from distutils.core import setup
setup (
    name = "zz_nester",
    version = "1.1.0",
    py_modules = ["zz_nester"],
    author = "adai041",
    author_url = "zhangzhiyong0819@126.com",
    url = "",
    description = "My first Python File",
)